@@ -4,5 +4,5 @@ from .views_api import members_view
 
 app_name = 'loducode_utils'
 urlpatterns = [
-    path('slack/members/', members_view, name='members_view')
+    path('slack/members/', members_view, name='members_view'),
 ]
\ No newline at end of file
